<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text" indent="no" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<!-- Deciding Params-->
	<xsl:param name="outfmt">10</xsl:param>
	<xsl:param name="deviceclass"/>
	<!-- Deciding Params-->
	<xsl:variable name="deviceClassNotFound">The device class requested is not present/enumerated.</xsl:variable>
	<xsl:variable name="spaceVar">15</xsl:variable>
	<xsl:variable name="maxColumnLen">79</xsl:variable>

	<xsl:template match="reportMap">
		<xsl:apply-templates select="consolidatedReport"/>
	</xsl:template>
	
	<xsl:template match="consolidatedReport">
		<xsl:variable name="reportCount" select="count(.//modReport)"/>
		<xsl:choose>
			<xsl:when test="$reportCount &gt; 0">
				<xsl:choose>
					<xsl:when test="$outfmt=11">
						<xsl:apply-templates select="modReport" mode="table"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="modReport" mode="list"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:value-of select="$deviceClassNotFound"/>
				<xsl:call-template name="NewLine"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="modReport" mode="list">
		<xsl:variable name="CTRLId" select="@ctrlid"/>
		<xsl:call-template name="NewLine"/>
		<xsl:apply-templates select="../../requestInfo[@ctrlid=$CTRLId]/device" mode="list"/>
		<xsl:apply-templates select="../../requestInfo[@ctrlid=$CTRLId]/test" mode="list"/>
		<xsl:call-template name="PopulateList">
			<xsl:with-param name="displayDirectives" select="../../DisplayDirective[@parentNode='modReport']"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="modReport" mode="table">
		<xsl:variable name="CTRLId" select="@ctrlid"/>
		<xsl:call-template name="NewLine"/>
		<xsl:apply-templates select="../../requestInfo[@ctrlid=$CTRLId]/device" mode="table"/>
		<xsl:apply-templates select="../../requestInfo[@ctrlid=$CTRLId]/test" mode="table"/>
		<xsl:call-template name="PopulateTable">
			<xsl:with-param name="noHeader" select="'true'"/>
			<xsl:with-param name="displayDirectives" select="../../DisplayDirective[@parentNode='modReport']"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="device" mode="list">
		<xsl:call-template name="PopulateList">
			<xsl:with-param name="displayDirectives" select="../../DisplayDirective[@parentNode='device']"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="test" mode="list">
		<xsl:call-template name="PopulateList">
			<xsl:with-param name="displayDirectives" select="../../DisplayDirective[@parentNode='test']"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="device" mode="table">
		<xsl:call-template name="PopulateTable">
			<xsl:with-param name="displayDirectives" select="../../DisplayDirective[@parentNode='device']"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="test" mode="table">
		<xsl:call-template name="PopulateTable">
			<xsl:with-param name="noHeader" select="'true'"/>
			<xsl:with-param name="displayDirectives" select="../../DisplayDirective[@parentNode='test']"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="PopulateList">
		<xsl:param name="index"/>
		<xsl:param name="displayDirectives"/>
		<xsl:variable name="nodeContent" select="."/>
		<xsl:for-each select="$displayDirectives">
			<xsl:sort order="ascending" select="@order" data-type="number"/>
			<xsl:variable name="elemname" select="@elemname"/>
			<xsl:variable name="dispname" select="@dispname"/>
			<xsl:if test="$elemname='deviceindex' or $elemname='testindex' or $nodeContent/*[name()=$elemname]/text() !=''">
				<xsl:choose>
					<xsl:when test="$elemname='evtString' ">
						<xsl:for-each select="$nodeContent/evtString">
							<xsl:sort order="ascending" select="@sequence" data-type="number"/>
							<xsl:call-template name="PrintListValues">
								<xsl:with-param name="nodeContent" select="."/>
								<xsl:with-param name="elemname" select="$elemname"/>
								<xsl:with-param name="index" select="$index"/>
								<xsl:with-param name="dispname" select="$dispname"/>
							</xsl:call-template>
							<xsl:call-template name="NewLine"/>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="PrintListValues">
							<xsl:with-param name="nodeContent" select="$nodeContent"/>
							<xsl:with-param name="elemname" select="$elemname"/>
							<xsl:with-param name="index" select="$index"/>
						</xsl:call-template>
						<xsl:call-template name="NewLine"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="PrintListValues">
		<xsl:param name="index"/>
		<xsl:param name="nodeContent"/>
		<xsl:param name="elemname"/>
		<xsl:param name="dispname"/>
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command">
				<xsl:choose>
					<xsl:when test="$dispname=''"><xsl:value-of select="@dispname"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="$dispname"/><xsl:text> </xsl:text><xsl:value-of select="position()"/></xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>:<xsl:text> </xsl:text>
		<xsl:choose>
			<xsl:when test="$elemname='deviceindex' or $elemname='testindex'"><xsl:value-of select="$index"/></xsl:when>
			<xsl:when test="$elemname='evtString'"><xsl:value-of select="$nodeContent"/></xsl:when>
			<xsl:otherwise><xsl:choose><xsl:when test="$elemname='deviceLocation'"><xsl:variable name="devFullLocation" select="normalize-space($nodeContent/*[name()=$elemname]/text())"/><xsl:call-template name="GiveOnlyLocation"><xsl:with-param name="devFullLocation" select="$devFullLocation"/></xsl:call-template></xsl:when><xsl:otherwise><xsl:value-of select="normalize-space($nodeContent/*[name()=$elemname]/text())"/></xsl:otherwise></xsl:choose>				
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="GiveOnlyLocation">
		<xsl:param name="devFullLocation"/>
		<xsl:choose>
			<xsl:when test="contains($devFullLocation, '!')">
				<xsl:call-template name="GiveOnlyLocation">
					<xsl:with-param name="devFullLocation" select="substring-after($devFullLocation, '!')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="$devFullLocation"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template> 
	<xsl:template name="CLISubCommand">
		<xsl:param name="command"/>
		<xsl:if test="$command != ''">
			<xsl:value-of select="$command"/>
			<xsl:call-template name="Listspaces">
				<xsl:with-param name="num">
					<xsl:value-of select="($spaceVar) -  string-length($command)"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="PopulateTable">
		<xsl:param name="index"/>
		<xsl:param name="noHeader"/>
		<xsl:param name="displayDirectives"/>
		<xsl:variable name="nodeContent" select="."/>
		<xsl:variable name="tmpattlen">
			<xsl:call-template name="MAX">
				<xsl:with-param name="list" select="$displayDirectives"/>
				<xsl:with-param name="type">display</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="tmpvallen">
			<xsl:call-template name="MAX">
				<xsl:with-param name="list" select="$displayDirectives"/>
				<xsl:with-param name="nodeContentVar" select="$nodeContent"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="maxatt">
			<xsl:choose>
				<xsl:when test="$tmpattlen &gt; '9'">
					<xsl:value-of select="$tmpattlen"/>
				</xsl:when>
				<xsl:otherwise>9</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="maxvalfirst">
			<xsl:choose>
				<xsl:when test="$tmpvallen &gt; '5'">
					<xsl:value-of select="$tmpvallen"/>
				</xsl:when>
				<xsl:otherwise>5</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="maxval">
			<xsl:choose>
				<xsl:when test="($maxColumnLen - ($maxatt + $maxvalfirst + 6) &gt; 0)">
					<xsl:value-of select="$maxvalfirst"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="($maxColumnLen - ($maxatt + 6))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>		
		<xsl:variable name="maxlength">
			<xsl:value-of select="$maxatt + $maxval + 6"/>
		</xsl:variable>
	<!--	[tmpattlen=<xsl:value-of select="$tmpattlen"/>;tmpvallen=<xsl:value-of  select="$tmpvallen"/>;maxatt=<xsl:value-of select="$maxatt"/>;maxval=<xsl:value-of  select="$maxval"/>;maxlength=<xsl:value-of select="$maxlength"/>] -->
     <xsl:if test="$noHeader=''">
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="$maxlength"/>
			<xsl:with-param name="character" select="'-'"/>
		</xsl:call-template>
		<xsl:call-template name="NewLine"/>
		<xsl:text> ATTRIBUTE</xsl:text>
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="($maxatt - 9)"/>
			<xsl:with-param name="character" select="' '"/>
		</xsl:call-template>
		<xsl:text> | VALUE</xsl:text>
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="($maxval - 5)"/>
			<xsl:with-param name="character" select="' '"/>
		</xsl:call-template>
		<xsl:call-template name="endRow"/>
		<xsl:call-template name="NewLine"/>
		</xsl:if>
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="$maxlength"/>
			<xsl:with-param name="character" select="'-'"/>
		</xsl:call-template>
		<xsl:call-template name="NewLine"/>
		<xsl:for-each select="$displayDirectives">
			<xsl:sort order="ascending" select="@order" data-type="number"/>
			<xsl:variable name="elemname" select="@elemname"/>
			<xsl:variable name="dispname" select="@dispname"/>
			<xsl:if test="$elemname='deviceindex' or $elemname='testindex' or $nodeContent/*[name()=$elemname]/text() !=''">
				<xsl:choose>
					<xsl:when test="$elemname='evtString' ">
						<xsl:for-each select="$nodeContent/evtString">
							<xsl:text> </xsl:text>
							<xsl:value-of select="$dispname"/><xsl:text> </xsl:text><xsl:value-of select="position()"/>
							<!--<xsl:variable name="leaveSpaces" select=""/> -->
							<xsl:call-template name="Tablespaces">
								<xsl:with-param name="length" select="($maxatt -  (string-length($dispname) + string-length(position()) +1 ))"/>
								<xsl:with-param name="character" select="' '"/>
							</xsl:call-template>
							<xsl:text> | </xsl:text>
							<xsl:call-template name="PrintValue"><xsl:with-param name="nodeContentVar" select="."/><xsl:with-param name="elemname" select="$elemname"/><xsl:with-param name="maxlength" select="$maxlength"/><xsl:with-param name="maxatt" select="$maxatt"/><xsl:with-param name="maxval" select="$maxval"/><xsl:with-param name="index" select="$index"/></xsl:call-template><xsl:variable name="printvallen"><xsl:value-of select="string-length(normalize-space(.))"/><!--<xsl:choose><xsl:when test="$elemname='deviceindex' or $elemname='testindex'"><xsl:value-of select="string-length($index)"/></xsl:when><xsl:otherwise><xsl:call-template name="MAX"><xsl:with-param name="list" select="."/><xsl:with-param name="nodeContentVar" select="."/></xsl:call-template></xsl:otherwise></xsl:choose>--></xsl:variable>
							<xsl:if test="$maxval &gt;= $printvallen">
								<xsl:call-template name="Tablespaces">
									<xsl:with-param name="length" select="($maxval -  $printvallen)"/>
									<xsl:with-param name="character" select="' '"/>
								</xsl:call-template>
								<xsl:call-template name="endRow"/>
							</xsl:if>
							<xsl:call-template name="NewLine"/>
							<xsl:call-template name="Tablespaces">
								<xsl:with-param name="length" select="$maxlength"/>
								<xsl:with-param name="character" select="'-'"/>
							</xsl:call-template>
							<xsl:call-template name="NewLine"/>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> </xsl:text>
						<xsl:value-of select="@dispname"/>
						<xsl:call-template name="Tablespaces">
							<xsl:with-param name="length" select="($maxatt -  string-length(@dispname))"/>
							<xsl:with-param name="character" select="' '"/>
						</xsl:call-template>
						<xsl:text> | </xsl:text>
						<xsl:call-template name="PrintValue"><xsl:with-param name="nodeContentVar" select="$nodeContent"/><xsl:with-param name="elemname" select="$elemname"/><xsl:with-param name="maxlength" select="$maxlength"/><xsl:with-param name="maxatt" select="$maxatt"/><xsl:with-param name="maxval" select="$maxval"/><xsl:with-param name="index" select="$index"/></xsl:call-template><xsl:variable name="printvallen"><xsl:choose><xsl:when test="$elemname='deviceindex' or $elemname='testindex'"><xsl:value-of select="string-length($index)"/></xsl:when><xsl:otherwise><xsl:call-template name="MAX"><xsl:with-param name="list" select="."/><xsl:with-param name="nodeContentVar" select="$nodeContent"/></xsl:call-template></xsl:otherwise></xsl:choose></xsl:variable>
						<xsl:if test="$maxval &gt;= $printvallen">
							<xsl:call-template name="Tablespaces">
								<xsl:with-param name="length" select="($maxval -  $printvallen)"/>
								<xsl:with-param name="character" select="' '"/>
							</xsl:call-template>
							<xsl:call-template name="endRow"/>
						</xsl:if>
						<xsl:call-template name="NewLine"/>
						<xsl:call-template name="Tablespaces">
							<xsl:with-param name="length" select="$maxlength"/>
							<xsl:with-param name="character" select="'-'"/>
						</xsl:call-template>
						<xsl:call-template name="NewLine"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="PrintValue">
		<xsl:param name="nodeContentVar"/>
		<xsl:param name="elemname"/>
		<xsl:param name="maxlength"/>
		<xsl:param name="maxatt"/>
		<xsl:param name="maxval"/>
		<xsl:param name="index"/>
		<xsl:choose>
			<xsl:when test="$elemname='deviceindex' or $elemname='testindex'"><xsl:value-of select="$index"/></xsl:when>
			<xsl:otherwise>
				<xsl:variable name="StringValue">
					<xsl:choose>
						<xsl:when test="$elemname='evtString'"><xsl:value-of select="normalize-space($nodeContentVar)"/></xsl:when>
						<xsl:when test="$elemname='deviceLocation'"><xsl:variable name="devFullLocation" select="normalize-space($nodeContentVar/*[name()=$elemname]/text())"/><xsl:call-template name="GiveOnlyLocation"><xsl:with-param name="devFullLocation" select="$devFullLocation"/></xsl:call-template></xsl:when>
						<xsl:otherwise><xsl:value-of select="normalize-space($nodeContentVar/*[name()=$elemname]/text())"/></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="StringValLength" select="string-length($StringValue)"/>
				<xsl:choose>
					<xsl:when test="($StringValLength &gt; $maxval)">
						<xsl:call-template name="BeautifyLengthyValue">
							<xsl:with-param name="StringValue" select="$StringValue"/>
							<xsl:with-param name="StringValLength" select="$StringValLength"/>
							<xsl:with-param name="maxatt" select="$maxatt"/>
							<xsl:with-param name="maxval" select="$maxval"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$StringValue"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="BeautifyLengthyValue">
		<xsl:param name="StringValue"/>
		<xsl:param name="StringValLength"/>
		<xsl:param name="maxatt"/>
		<xsl:param name="maxval"/>
		<xsl:param name="secondOnwards"/>
		<xsl:choose>
			<xsl:when test="($StringValLength &gt; $maxval)">
				<xsl:if test="$secondOnwards = 'yes'">
					<xsl:call-template name="Tablespaces">
						<xsl:with-param name="length" select="$maxatt + 1"/>
						<xsl:with-param name="character" select="' '"/>
					</xsl:call-template>
					<xsl:text> | </xsl:text>
				</xsl:if>
				<xsl:value-of select="substring($StringValue, 0, $maxval+1)"/>
				<xsl:call-template name="endRow"/>
				<xsl:call-template name="NewLine"/>
				<xsl:call-template name="BeautifyLengthyValue">
					<xsl:with-param name="StringValue" select="substring($StringValue, ($maxval+1))"/>
					<xsl:with-param name="StringValLength" select="string-length(substring($StringValue, ($maxval+1)))"/>
					<xsl:with-param name="maxatt" select="$maxatt"/>
					<xsl:with-param name="maxval" select="$maxval"/>
					<xsl:with-param name="secondOnwards" select="'yes'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="Tablespaces">
					<xsl:with-param name="length" select="$maxatt + 1"/>
					<xsl:with-param name="character" select="' '"/>
				</xsl:call-template>
				<xsl:text> | </xsl:text>
				<xsl:value-of select="$StringValue"/>
				<xsl:call-template name="Tablespaces">
					<xsl:with-param name="length" select="($maxColumnLen - (string-length($StringValue) + $maxatt + 6))"/>
					<xsl:with-param name="character" select="' '"/>
				</xsl:call-template>
				<xsl:call-template name="endRow"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="startRow">
		<xsl:text>| </xsl:text>
	</xsl:template>
	<xsl:template name="endRow">
		<xsl:text> |</xsl:text>
	</xsl:template>

	<xsl:template name="MAX">
		<xsl:param name="list"/>
		<xsl:param name="nodeContentVar"/>
		<xsl:param name="type"/>
		<xsl:choose>
			<xsl:when test="$list">
				<xsl:variable name="first">
					<xsl:choose>
						<xsl:when test="$type='display'">
							<xsl:value-of select="string-length(normalize-space($list[1]/@dispname))"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="$list[1]">
								<xsl:sort order="ascending" select="@order" data-type="number"/>
								<xsl:call-template name="PrintLength">
									<xsl:with-param name="nodeContentVar" select="$nodeContentVar"/>
									<xsl:with-param name="elemname" select="@elemname"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="rest">
					<xsl:call-template name="MAX">
						<xsl:with-param name="list" select="$list[position()!=1]"/>
						<xsl:with-param name="nodeContentVar" select="$nodeContentVar"/>
						<xsl:with-param name="type" select="$type"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<!--The following translate stuff removes spurious  comma inserted when in French or German Locale under Linux 7.2  -->
					<xsl:when test="normalize-space(translate($first,',','  ')) &gt; normalize-space(translate($rest,',',' ')) ">
						<xsl:value-of select="normalize-space(translate($first,',',' '))"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$rest"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="PrintLength">
		<xsl:param name="nodeContentVar"/>
		<xsl:param name="elemname"/>
		<xsl:choose><xsl:when test="$elemname='deviceLocation'"><xsl:variable name="devFullLocation" select="normalize-space($nodeContentVar/*[name()=$elemname]/text())"/><xsl:variable name="strOnlyLocation"><xsl:call-template name="GiveOnlyLocation"><xsl:with-param name="devFullLocation" select="$devFullLocation"/></xsl:call-template></xsl:variable><xsl:value-of select="string-length($strOnlyLocation)"/></xsl:when><xsl:otherwise><xsl:value-of select="string-length(normalize-space($nodeContentVar/*[name()=$elemname]/text()))"/></xsl:otherwise></xsl:choose>
	</xsl:template>

	<xsl:template name="Listspaces">
		<xsl:param name="num"/>
		<xsl:text> </xsl:text>
		<xsl:if test="$num &gt; '0'">
			<xsl:call-template name="Listspaces">
				<xsl:with-param name="num">
					<xsl:value-of select="($num) - 1"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="Tablespaces">
		<xsl:param name="length"/>
		<xsl:param name="character"/>
		<xsl:if test="$length!=0">
			<xsl:value-of select="$character"/>
			<xsl:call-template name="Tablespaces">
				<!--The following translate stuff removes spurious comma  inserted when in French or German Locale under Linux 7.2  -->
				<xsl:with-param name="length"  select="normalize-space(translate($length,',',' '))-1"/>
				<xsl:with-param name="character" select="$character"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
	<xsl:template match="*"></xsl:template>
</xsl:stylesheet>
