<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<!-- Deciding Params-->
	<xsl:param name="outfmt">12</xsl:param>
	<xsl:param name="deviceclass"/>
	<!-- Deciding Params-->
	<xsl:variable name="deviceClassNotFound">The device class requested is not present/enumerated.</xsl:variable>

	<xsl:template match="reportMap">
		<xsl:apply-templates select="consolidatedReport"/>
	</xsl:template>
	
	<xsl:template match="consolidatedReport">
		<xsl:variable name="reportCount" select="count(.//modReport)"/>
		<xsl:choose>
			<xsl:when test="$reportCount &gt; 0">
				<xsl:call-template name="NewLine"/>
				<xsl:element name="reportMap">
					<xsl:apply-templates select="modReport" mode="xml"/>
				</xsl:element>
				<xsl:call-template name="NewLine"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:value-of select="$deviceClassNotFound"/>
				<xsl:call-template name="NewLine"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="modReport" mode="xml">
		<xsl:variable name="CTRLId" select="@ctrlid"/>
		<xsl:copy>
			<xsl:apply-templates select="../../requestInfo[@ctrlid=$CTRLId]/device" mode="xml"/>
			<xsl:apply-templates select="../../requestInfo[@ctrlid=$CTRLId]/test" mode="xml"/>
			<xsl:apply-templates select="node()" mode="xml"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="device" mode="xml">
		<xsl:apply-templates select="deviceName" mode="xml"/>
		<xsl:apply-templates select="deviceDescription" mode="xml"/>
		<xsl:apply-templates select="deviceLocation" mode="xml"/>
	</xsl:template>

	<xsl:template match="test" mode="xml">
		<xsl:apply-templates select="testName" mode="xml"/>
		<xsl:apply-templates select="testDescription" mode="xml"/>
	</xsl:template>
	
	<xsl:template match="@* | node() | deviceName | deviceDescription | deviceLocation | testName | testDescription" mode="xml"> 
		<xsl:if test="(name() != '_Key') and (name() !='sequenceKey')">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="node()" mode="xml"/>
		</xsl:copy>
		</xsl:if>
	</xsl:template>

	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
	<xsl:template match="*"></xsl:template>
</xsl:stylesheet>
