#!/bin/sh 
###############################################################################
#
#       Dell Inc. PROPRIETARY INFORMATION
#
# This software is supplied under the terms of a license agreement or
# nondisclosure agreement with Dell Inc. and may not
# be copied or disclosed except in accordance with the terms of that
# agreement.
#
# Copyright (c) 2000-2007 Dell Inc. All Rights Reserved.
#
# Module Name:
#
#   install.sh
#
# Abstract/Purpose:
#
#   This script will enable the user to install all the dependent 
#   components required by Dell(R) PowerEdge(R) Diagnostics.
#
# Environment:
#
#   Linux
#
###############################################################################

cd `dirname $0`

omilPackage=srvadmin-omilcore-5.2.0-*.rpm
hapiPackage=srvadmin-hapi-5.2.0-*.rpm
litePackage=dell-pediags-2.9.0-*.rpm
ipmiPackage=srvadmin-ipmi-5.2.0-*.rpm

echo_success() {
    echo -en "\t" [ 
    echo -en "\\033[1;32m" OK 
    echo -en "\\033[0;39m" ]
    echo
}

echo_fail() {
    echo -en "\t" [ 
    echo -en "\\033[1;31m" FAILED 
    echo -en "\\033[0;39m" ]
    echo
}

if [ ${UID} != 0 ]; then
   echo You need root-user privileges to install this product.
   echo
   exit 1
fi

ipmiVer=`/usr/sbin/dmidecode | grep -A 8 "Handle 0x2600" | awk '/Version:/ {print $3}'`

rpm -q DellPEDiags >/dev/null
if test $? -eq 0; then
   echo Uninstall the older version of PowerEdge Diagnostics before installing this version.
   echo
   exit 2
else
   more ./license.txt
   echo ""
   echo -n "Do you agree to the above license terms? ('y' for yes | 'Enter' to exit): "
   read RESP
   resp=`echo "${RESP}" | sed 's#^[[:space:]]*##; s#[[:space:]]*$##'`
   if echo "${resp}" | grep -qi "^y$" ; then
 if test -f /var/lock/.spsetup; then
   echo DUP is running. Please retry later.
 else
   if which omreport >/dev/null 2>&1; then
      echo OMSA is installed - ignoring dependencies
   elif ! test -z $ipmiVer; then
      omilFlags="--nodeps"
      if rpm -q --whatprovides srvadmin-omilcore >/dev/null 2>&1; then
         echo -n Upgrading srvadmin-omilcore:
         omilDeps=`rpm -q --whatrequires srvadmin-omilcore|grep -v srvadmin-omilcore`
         if ! test -z "`echo $omilDeps | grep -v -i srvadmin-hapi`"; then
            echo WARNING: Found dependencies. Repackaging srvadmin-omilcore...
            omilFlags="$omilFlags --repackage"
         fi
      else
         echo -ne Installing srvadmin-omilcore:
      fi
      test -f /var/lock/.spsetup \
      || OMIIGNORESYSID=true rpm -Uhv $omilPackage $omilFlags >/dev/null 2>&1

      if test $? -eq 0; then
	echo_success 
      else
        rpm -q srvadmin-omilcore >/dev/null
        if test $? -eq 0; then
          echo " srvadmin-omilcore is already installed on this system."
        else
          echo_fail
        fi
      fi

      if rpm -q --whatprovides srvadmin-ipmi >/dev/null 2>&1; then
         ipmiFlags="$ipmiFlags --nodeps"
         echo -n Upgrading srvadmin-ipmi:
      else
         echo -ne Installing srvadmin-ipmi:
      fi
      test -f /var/lock/.spsetup \
      || OMIIGNORESYSID=true rpm -Uhv $ipmiPackage $ipmiFlags >/dev/null 2>&1

      if test $? -eq 0; then
	echo_success
      else
        rpm -q srvadmin-ipmi >/dev/null
        if test $? -eq 0; then
          echo " srvadmin-ipmi is already installed on this system."
        else
          echo_fail
        fi
      fi
      
      if rpm -q --whatprovides libdchapi32.so.5 >/dev/null 2>&1; then
        echo -ne Upgrading srvadmin-hapi:
        test -f /var/lock/.spsetup || rpm -ev instsvc-drivers 2>/dev/null
      else
        echo -ne Installing srvadmin-hapi:
      fi
      test -f /var/lock/.spsetup \
      || OMIIGNORESYSID=true rpm -Uhv $hapiPackage >/dev/null 2>&1

      if test $? -eq 0; then
	echo_success
#        echo Starting services
        srvadmin-services.sh start
      else
        rpm -q srvadmin-hapi >/dev/null
        if test $? -eq 0; then
          echo " srvadmin-hapi is already installed on this system."
        else
          echo_fail
          echo -e "\nWARNING: Memory and DRAC 5 diagnostics will not be available due to installation failure of srvadmin-hapi component. Refer to SETUP section in readme.txt for detailed installation instructions."

          echo -en "\nRolling back srvadmin-ipmi as srvadmin-hapi failed to install:"
          liteFlags="$liteFlags --nodeps"
          test -f /var/lock/.spsetup || rpm -ev srvadmin-ipmi 2>/dev/null
          if test $? -eq 0; then
	     echo_success
          else
             echo_fail
	  fi

          echo -en "\nRolling back srvadmin-omilcore as srvadmin-hapi failed to install:"
          test -f /var/lock/.spsetup || rpm -ev srvadmin-omilcore 2>/dev/null
          if test $? -eq 0; then
	     echo_success
          else
             echo_fail
	  fi
        fi
      fi
   else
      liteFlags="$liteFlags --nodeps"
      echo -ne "\nSystem does not support IPMI"
      echo_success
   fi

   # 
   # check for presence of pciutils and usbutils
   #
   rpm -q pciutils > /dev/null 2>&1
   if test $? -ne 0; then
      echo -e "\nWARNING: Certain diagnostics tests may not be available because the pciutils package is missing. Install pciutils from the OS distribution CD before running PowerEdge Diagnostics."
   fi
   
   rpm -q usbutils > /dev/null 2>&1
   if test $? -ne 0; then
      echo -e "\nWARNING: USB diagnostics tests will not be available because the usbutils package is missing. Install usbutils from the OS distribution CD before running PowerEdge Diagnostics."
      liteFlags="$liteFlags --nodeps"
   fi

   if rpm -q --whatprovides dell-pediags >/dev/null 2>&1; then
      echo -ne Upgrading dell-pediags:
   else
      echo -en "\nInstalling dell-pediags:"
   fi
   test -f /var/lock/.spsetup || rpm -Uhv $litePackage $liteFlags >/dev/null 2>&1
   if test $? -eq 0; then
      echo_success
   else
      rpm -q dell-pediags >/dev/null
      if test $? -eq 0; then
         echo " dell-pediags-2.9.0 is already installed on this system."
      else
         echo_fail
         echo " Installation may have failed due to missing dependencies or insufficient disk space. For details on installer requirements please refer to the README file."
      fi
   fi
   fi
   else
     exit 1
 fi
fi
